Class: Google::Cloud::Bigquery::Reservation::V1::Assignment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb

Overview

An assignment allows a project to submit jobs of a certain type using slots from the specified reservation.

Defined Under Namespace

Modules: JobType, State

Instance Attribute Summary collapse

Instance Attribute Details

#assignee::String

Returns Optional. The resource which will use the reservation. E.g. projects/myproject, folders/123, or organizations/456.

Returns:

  • (::String)

    Optional. The resource which will use the reservation. E.g. projects/myproject, folders/123, or organizations/456.



850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 850

class Assignment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of job, which could be specified when using the reservation.
  module JobType
    # Invalid type. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    JOB_TYPE_UNSPECIFIED = 0

    # Pipeline (load/export) jobs from the project will use the reservation.
    PIPELINE = 1

    # Query jobs from the project will use the reservation.
    QUERY = 2

    # BigQuery ML jobs that use services external to BigQuery for model
    # training. These jobs will not utilize idle slots from other reservations.
    ML_EXTERNAL = 3

    # Background jobs that BigQuery runs for the customers in the background.
    BACKGROUND = 4

    # Continuous SQL jobs will use this reservation. Reservations with
    # continuous assignments cannot be mixed with non-continuous assignments.
    CONTINUOUS = 6

    # Finer granularity background jobs for capturing changes in a source
    # database and streaming them into BigQuery. Reservations with this job
    # type take priority over a default BACKGROUND reservation assignment (if
    # it exists).
    BACKGROUND_CHANGE_DATA_CAPTURE = 7

    # Finer granularity background jobs for refreshing cached metadata for
    # BigQuery tables. Reservations with this job type take priority over a
    # default BACKGROUND reservation assignment (if it exists).
    BACKGROUND_COLUMN_METADATA_INDEX = 8

    # Finer granularity background jobs for refreshing search indexes upon
    # BigQuery table columns. Reservations with this job type
    # take priority over a default BACKGROUND reservation assignment (if it
    # exists).
    BACKGROUND_SEARCH_INDEX_REFRESH = 9
  end

  # Assignment will remain in PENDING state if no active capacity commitment is
  # present. It will become ACTIVE when some capacity commitment becomes
  # active.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Queries from assignee will be executed as on-demand, if related
    # assignment is pending.
    PENDING = 1

    # Assignment is ready.
    ACTIVE = 2
  end
end

#enable_gemini_in_bigquery::Boolean

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Optional. Deprecated: "Gemini in BigQuery" is now available by default for all BigQuery editions and should not be explicitly set. Controls if "Gemini in BigQuery" (https://cloud.google.com/gemini/docs/bigquery/overview) features should be enabled for this reservation assignment.

Returns:

  • (::Boolean)

    Optional. Deprecated: "Gemini in BigQuery" is now available by default for all BigQuery editions and should not be explicitly set. Controls if "Gemini in BigQuery" (https://cloud.google.com/gemini/docs/bigquery/overview) features should be enabled for this reservation assignment.



850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 850

class Assignment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of job, which could be specified when using the reservation.
  module JobType
    # Invalid type. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    JOB_TYPE_UNSPECIFIED = 0

    # Pipeline (load/export) jobs from the project will use the reservation.
    PIPELINE = 1

    # Query jobs from the project will use the reservation.
    QUERY = 2

    # BigQuery ML jobs that use services external to BigQuery for model
    # training. These jobs will not utilize idle slots from other reservations.
    ML_EXTERNAL = 3

    # Background jobs that BigQuery runs for the customers in the background.
    BACKGROUND = 4

    # Continuous SQL jobs will use this reservation. Reservations with
    # continuous assignments cannot be mixed with non-continuous assignments.
    CONTINUOUS = 6

    # Finer granularity background jobs for capturing changes in a source
    # database and streaming them into BigQuery. Reservations with this job
    # type take priority over a default BACKGROUND reservation assignment (if
    # it exists).
    BACKGROUND_CHANGE_DATA_CAPTURE = 7

    # Finer granularity background jobs for refreshing cached metadata for
    # BigQuery tables. Reservations with this job type take priority over a
    # default BACKGROUND reservation assignment (if it exists).
    BACKGROUND_COLUMN_METADATA_INDEX = 8

    # Finer granularity background jobs for refreshing search indexes upon
    # BigQuery table columns. Reservations with this job type
    # take priority over a default BACKGROUND reservation assignment (if it
    # exists).
    BACKGROUND_SEARCH_INDEX_REFRESH = 9
  end

  # Assignment will remain in PENDING state if no active capacity commitment is
  # present. It will become ACTIVE when some capacity commitment becomes
  # active.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Queries from assignee will be executed as on-demand, if related
    # assignment is pending.
    PENDING = 1

    # Assignment is ready.
    ACTIVE = 2
  end
end

#job_type::Google::Cloud::Bigquery::Reservation::V1::Assignment::JobType

Returns Optional. Which type of jobs will use the reservation.

Returns:



850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 850

class Assignment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of job, which could be specified when using the reservation.
  module JobType
    # Invalid type. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    JOB_TYPE_UNSPECIFIED = 0

    # Pipeline (load/export) jobs from the project will use the reservation.
    PIPELINE = 1

    # Query jobs from the project will use the reservation.
    QUERY = 2

    # BigQuery ML jobs that use services external to BigQuery for model
    # training. These jobs will not utilize idle slots from other reservations.
    ML_EXTERNAL = 3

    # Background jobs that BigQuery runs for the customers in the background.
    BACKGROUND = 4

    # Continuous SQL jobs will use this reservation. Reservations with
    # continuous assignments cannot be mixed with non-continuous assignments.
    CONTINUOUS = 6

    # Finer granularity background jobs for capturing changes in a source
    # database and streaming them into BigQuery. Reservations with this job
    # type take priority over a default BACKGROUND reservation assignment (if
    # it exists).
    BACKGROUND_CHANGE_DATA_CAPTURE = 7

    # Finer granularity background jobs for refreshing cached metadata for
    # BigQuery tables. Reservations with this job type take priority over a
    # default BACKGROUND reservation assignment (if it exists).
    BACKGROUND_COLUMN_METADATA_INDEX = 8

    # Finer granularity background jobs for refreshing search indexes upon
    # BigQuery table columns. Reservations with this job type
    # take priority over a default BACKGROUND reservation assignment (if it
    # exists).
    BACKGROUND_SEARCH_INDEX_REFRESH = 9
  end

  # Assignment will remain in PENDING state if no active capacity commitment is
  # present. It will become ACTIVE when some capacity commitment becomes
  # active.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Queries from assignee will be executed as on-demand, if related
    # assignment is pending.
    PENDING = 1

    # Assignment is ready.
    ACTIVE = 2
  end
end

#name::String (readonly)

Returns Output only. Name of the resource. E.g.: projects/myproject/locations/US/reservations/team1-prod/assignments/123. The assignment_id must only contain lower case alphanumeric characters or dashes and the max length is 64 characters.

Returns:

  • (::String)

    Output only. Name of the resource. E.g.: projects/myproject/locations/US/reservations/team1-prod/assignments/123. The assignment_id must only contain lower case alphanumeric characters or dashes and the max length is 64 characters.



850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 850

class Assignment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of job, which could be specified when using the reservation.
  module JobType
    # Invalid type. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    JOB_TYPE_UNSPECIFIED = 0

    # Pipeline (load/export) jobs from the project will use the reservation.
    PIPELINE = 1

    # Query jobs from the project will use the reservation.
    QUERY = 2

    # BigQuery ML jobs that use services external to BigQuery for model
    # training. These jobs will not utilize idle slots from other reservations.
    ML_EXTERNAL = 3

    # Background jobs that BigQuery runs for the customers in the background.
    BACKGROUND = 4

    # Continuous SQL jobs will use this reservation. Reservations with
    # continuous assignments cannot be mixed with non-continuous assignments.
    CONTINUOUS = 6

    # Finer granularity background jobs for capturing changes in a source
    # database and streaming them into BigQuery. Reservations with this job
    # type take priority over a default BACKGROUND reservation assignment (if
    # it exists).
    BACKGROUND_CHANGE_DATA_CAPTURE = 7

    # Finer granularity background jobs for refreshing cached metadata for
    # BigQuery tables. Reservations with this job type take priority over a
    # default BACKGROUND reservation assignment (if it exists).
    BACKGROUND_COLUMN_METADATA_INDEX = 8

    # Finer granularity background jobs for refreshing search indexes upon
    # BigQuery table columns. Reservations with this job type
    # take priority over a default BACKGROUND reservation assignment (if it
    # exists).
    BACKGROUND_SEARCH_INDEX_REFRESH = 9
  end

  # Assignment will remain in PENDING state if no active capacity commitment is
  # present. It will become ACTIVE when some capacity commitment becomes
  # active.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Queries from assignee will be executed as on-demand, if related
    # assignment is pending.
    PENDING = 1

    # Assignment is ready.
    ACTIVE = 2
  end
end

#principal::String

Returns Optional. Represents the principal for this assignment. If not empty, jobs run by this principal will utilize the associated reservation. Otherwise, jobs will fall back to using the reservation assigned to the project, folder, or organization (in that order). If no reservation is assigned at any of these levels, on-demand capacity will be used.

The supported formats are:

  • principal://goog/subject/USER_EMAIL_ADDRESS for users,
  • principal://iam.googleapis.com/projects/-/serviceAccounts/SA_EMAIL_ADDRESS for service accounts,
  • principal://iam.googleapis.com/projects/PROJECT_NUMBER/locations/global/workloadIdentityPools/POOL_ID/subject/SUBJECT_ID for workload identity pool identities.
  • The special value unknown_or_deleted_user represents principals which cannot be read from the user info service, for example deleted users.

Returns:

  • (::String)

    Optional. Represents the principal for this assignment. If not empty, jobs run by this principal will utilize the associated reservation. Otherwise, jobs will fall back to using the reservation assigned to the project, folder, or organization (in that order). If no reservation is assigned at any of these levels, on-demand capacity will be used.

    The supported formats are:

    • principal://goog/subject/USER_EMAIL_ADDRESS for users,
    • principal://iam.googleapis.com/projects/-/serviceAccounts/SA_EMAIL_ADDRESS for service accounts,
    • principal://iam.googleapis.com/projects/PROJECT_NUMBER/locations/global/workloadIdentityPools/POOL_ID/subject/SUBJECT_ID for workload identity pool identities.
    • The special value unknown_or_deleted_user represents principals which cannot be read from the user info service, for example deleted users.


850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 850

class Assignment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of job, which could be specified when using the reservation.
  module JobType
    # Invalid type. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    JOB_TYPE_UNSPECIFIED = 0

    # Pipeline (load/export) jobs from the project will use the reservation.
    PIPELINE = 1

    # Query jobs from the project will use the reservation.
    QUERY = 2

    # BigQuery ML jobs that use services external to BigQuery for model
    # training. These jobs will not utilize idle slots from other reservations.
    ML_EXTERNAL = 3

    # Background jobs that BigQuery runs for the customers in the background.
    BACKGROUND = 4

    # Continuous SQL jobs will use this reservation. Reservations with
    # continuous assignments cannot be mixed with non-continuous assignments.
    CONTINUOUS = 6

    # Finer granularity background jobs for capturing changes in a source
    # database and streaming them into BigQuery. Reservations with this job
    # type take priority over a default BACKGROUND reservation assignment (if
    # it exists).
    BACKGROUND_CHANGE_DATA_CAPTURE = 7

    # Finer granularity background jobs for refreshing cached metadata for
    # BigQuery tables. Reservations with this job type take priority over a
    # default BACKGROUND reservation assignment (if it exists).
    BACKGROUND_COLUMN_METADATA_INDEX = 8

    # Finer granularity background jobs for refreshing search indexes upon
    # BigQuery table columns. Reservations with this job type
    # take priority over a default BACKGROUND reservation assignment (if it
    # exists).
    BACKGROUND_SEARCH_INDEX_REFRESH = 9
  end

  # Assignment will remain in PENDING state if no active capacity commitment is
  # present. It will become ACTIVE when some capacity commitment becomes
  # active.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Queries from assignee will be executed as on-demand, if related
    # assignment is pending.
    PENDING = 1

    # Assignment is ready.
    ACTIVE = 2
  end
end

#scheduling_policy::Google::Cloud::Bigquery::Reservation::V1::SchedulingPolicy

Returns Optional. The scheduling policy to use for jobs and queries of this assignee when running under the associated reservation. The scheduling policy controls how the reservation's resources are distributed. This overrides the default scheduling policy specified on the reservation.

This feature is not yet generally available.

Returns:

  • (::Google::Cloud::Bigquery::Reservation::V1::SchedulingPolicy)

    Optional. The scheduling policy to use for jobs and queries of this assignee when running under the associated reservation. The scheduling policy controls how the reservation's resources are distributed. This overrides the default scheduling policy specified on the reservation.

    This feature is not yet generally available.



850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 850

class Assignment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of job, which could be specified when using the reservation.
  module JobType
    # Invalid type. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    JOB_TYPE_UNSPECIFIED = 0

    # Pipeline (load/export) jobs from the project will use the reservation.
    PIPELINE = 1

    # Query jobs from the project will use the reservation.
    QUERY = 2

    # BigQuery ML jobs that use services external to BigQuery for model
    # training. These jobs will not utilize idle slots from other reservations.
    ML_EXTERNAL = 3

    # Background jobs that BigQuery runs for the customers in the background.
    BACKGROUND = 4

    # Continuous SQL jobs will use this reservation. Reservations with
    # continuous assignments cannot be mixed with non-continuous assignments.
    CONTINUOUS = 6

    # Finer granularity background jobs for capturing changes in a source
    # database and streaming them into BigQuery. Reservations with this job
    # type take priority over a default BACKGROUND reservation assignment (if
    # it exists).
    BACKGROUND_CHANGE_DATA_CAPTURE = 7

    # Finer granularity background jobs for refreshing cached metadata for
    # BigQuery tables. Reservations with this job type take priority over a
    # default BACKGROUND reservation assignment (if it exists).
    BACKGROUND_COLUMN_METADATA_INDEX = 8

    # Finer granularity background jobs for refreshing search indexes upon
    # BigQuery table columns. Reservations with this job type
    # take priority over a default BACKGROUND reservation assignment (if it
    # exists).
    BACKGROUND_SEARCH_INDEX_REFRESH = 9
  end

  # Assignment will remain in PENDING state if no active capacity commitment is
  # present. It will become ACTIVE when some capacity commitment becomes
  # active.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Queries from assignee will be executed as on-demand, if related
    # assignment is pending.
    PENDING = 1

    # Assignment is ready.
    ACTIVE = 2
  end
end

#state::Google::Cloud::Bigquery::Reservation::V1::Assignment::State (readonly)

Returns Output only. State of the assignment.

Returns:



850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 850

class Assignment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of job, which could be specified when using the reservation.
  module JobType
    # Invalid type. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    JOB_TYPE_UNSPECIFIED = 0

    # Pipeline (load/export) jobs from the project will use the reservation.
    PIPELINE = 1

    # Query jobs from the project will use the reservation.
    QUERY = 2

    # BigQuery ML jobs that use services external to BigQuery for model
    # training. These jobs will not utilize idle slots from other reservations.
    ML_EXTERNAL = 3

    # Background jobs that BigQuery runs for the customers in the background.
    BACKGROUND = 4

    # Continuous SQL jobs will use this reservation. Reservations with
    # continuous assignments cannot be mixed with non-continuous assignments.
    CONTINUOUS = 6

    # Finer granularity background jobs for capturing changes in a source
    # database and streaming them into BigQuery. Reservations with this job
    # type take priority over a default BACKGROUND reservation assignment (if
    # it exists).
    BACKGROUND_CHANGE_DATA_CAPTURE = 7

    # Finer granularity background jobs for refreshing cached metadata for
    # BigQuery tables. Reservations with this job type take priority over a
    # default BACKGROUND reservation assignment (if it exists).
    BACKGROUND_COLUMN_METADATA_INDEX = 8

    # Finer granularity background jobs for refreshing search indexes upon
    # BigQuery table columns. Reservations with this job type
    # take priority over a default BACKGROUND reservation assignment (if it
    # exists).
    BACKGROUND_SEARCH_INDEX_REFRESH = 9
  end

  # Assignment will remain in PENDING state if no active capacity commitment is
  # present. It will become ACTIVE when some capacity commitment becomes
  # active.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Queries from assignee will be executed as on-demand, if related
    # assignment is pending.
    PENDING = 1

    # Assignment is ready.
    ACTIVE = 2
  end
end