Class: Google::Cloud::Bigquery::Reservation::V1::CapacityCommitment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb

Overview

Capacity commitment is a way to purchase compute capacity for BigQuery jobs (in the form of slots) with some committed period of usage. Annual commitments renew by default. Commitments can be removed after their commitment end time passes.

In order to remove annual commitment, its plan needs to be changed to monthly or flex first.

A capacity commitment resource exists as a child resource of the admin project.

Defined Under Namespace

Modules: CommitmentPlan, State

Instance Attribute Summary collapse

Instance Attribute Details

#commitment_end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The end of the current commitment period. It is applicable only for ACTIVE capacity commitments. Note after renewal, commitment_end_time is the time the renewed commitment expires. So itwould be at a time after commitment_start_time + committed period, because we don't change commitment_start_time ,.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The end of the current commitment period. It is applicable only for ACTIVE capacity commitments. Note after renewal, commitment_end_time is the time the renewed commitment expires. So itwould be at a time after commitment_start_time + committed period, because we don't change commitment_start_time ,



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 403

class CapacityCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Commitment plan defines the current committed period. Capacity commitment
  # cannot be deleted during it's committed period.
  module CommitmentPlan
    # Invalid plan value. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    COMMITMENT_PLAN_UNSPECIFIED = 0

    # Flex commitments have committed period of 1 minute after becoming ACTIVE.
    # After that, they are not in a committed period anymore and can be removed
    # any time.
    FLEX = 3

    # Same as FLEX, should only be used if flat-rate commitments are still
    # available.
    FLEX_FLAT_RATE = 7

    # Trial commitments have a committed period of 182 days after becoming
    # ACTIVE. After that, they are converted to a new commitment based on the
    # `renewal_plan`. Default `renewal_plan` for Trial commitment is Flex so
    # that it can be deleted right after committed period ends.
    TRIAL = 5

    # Monthly commitments have a committed period of 30 days after becoming
    # ACTIVE. After that, they are not in a committed period anymore and can be
    # removed any time.
    MONTHLY = 2

    # Same as MONTHLY, should only be used if flat-rate commitments are still
    # available.
    MONTHLY_FLAT_RATE = 8

    # Annual commitments have a committed period of 365 days after becoming
    # ACTIVE. After that they are converted to a new commitment based on the
    # renewal_plan.
    ANNUAL = 4

    # Same as ANNUAL, should only be used if flat-rate commitments are still
    # available.
    ANNUAL_FLAT_RATE = 9

    # 3-year commitments have a committed period of 1095(3 * 365) days after
    # becoming ACTIVE. After that they are converted to a new commitment based
    # on the renewal_plan.
    THREE_YEAR = 10

    # Should only be used for `renewal_plan` and is only meaningful if
    # edition is specified to values other than EDITION_UNSPECIFIED. Otherwise
    # CreateCapacityCommitmentRequest or UpdateCapacityCommitmentRequest will
    # be rejected with error code `google.rpc.Code.INVALID_ARGUMENT`. If the
    # renewal_plan is NONE, capacity commitment will be removed at the end of
    # its commitment period.
    NONE = 6
  end

  # Capacity commitment can either become ACTIVE right away or transition
  # from PENDING to ACTIVE or FAILED.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Capacity commitment is pending provisioning. Pending capacity commitment
    # does not contribute to the project's slot_capacity.
    PENDING = 1

    # Once slots are provisioned, capacity commitment becomes active.
    # slot_count is added to the project's slot_capacity.
    ACTIVE = 2

    # Capacity commitment is failed to be activated by the backend.
    FAILED = 3
  end
end

#commitment_start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The start of the current commitment period. It is applicable only for ACTIVE capacity commitments. Note after the commitment is renewed, commitment_start_time won't be changed. It refers to the start time of the original commitment.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The start of the current commitment period. It is applicable only for ACTIVE capacity commitments. Note after the commitment is renewed, commitment_start_time won't be changed. It refers to the start time of the original commitment.



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 403

class CapacityCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Commitment plan defines the current committed period. Capacity commitment
  # cannot be deleted during it's committed period.
  module CommitmentPlan
    # Invalid plan value. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    COMMITMENT_PLAN_UNSPECIFIED = 0

    # Flex commitments have committed period of 1 minute after becoming ACTIVE.
    # After that, they are not in a committed period anymore and can be removed
    # any time.
    FLEX = 3

    # Same as FLEX, should only be used if flat-rate commitments are still
    # available.
    FLEX_FLAT_RATE = 7

    # Trial commitments have a committed period of 182 days after becoming
    # ACTIVE. After that, they are converted to a new commitment based on the
    # `renewal_plan`. Default `renewal_plan` for Trial commitment is Flex so
    # that it can be deleted right after committed period ends.
    TRIAL = 5

    # Monthly commitments have a committed period of 30 days after becoming
    # ACTIVE. After that, they are not in a committed period anymore and can be
    # removed any time.
    MONTHLY = 2

    # Same as MONTHLY, should only be used if flat-rate commitments are still
    # available.
    MONTHLY_FLAT_RATE = 8

    # Annual commitments have a committed period of 365 days after becoming
    # ACTIVE. After that they are converted to a new commitment based on the
    # renewal_plan.
    ANNUAL = 4

    # Same as ANNUAL, should only be used if flat-rate commitments are still
    # available.
    ANNUAL_FLAT_RATE = 9

    # 3-year commitments have a committed period of 1095(3 * 365) days after
    # becoming ACTIVE. After that they are converted to a new commitment based
    # on the renewal_plan.
    THREE_YEAR = 10

    # Should only be used for `renewal_plan` and is only meaningful if
    # edition is specified to values other than EDITION_UNSPECIFIED. Otherwise
    # CreateCapacityCommitmentRequest or UpdateCapacityCommitmentRequest will
    # be rejected with error code `google.rpc.Code.INVALID_ARGUMENT`. If the
    # renewal_plan is NONE, capacity commitment will be removed at the end of
    # its commitment period.
    NONE = 6
  end

  # Capacity commitment can either become ACTIVE right away or transition
  # from PENDING to ACTIVE or FAILED.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Capacity commitment is pending provisioning. Pending capacity commitment
    # does not contribute to the project's slot_capacity.
    PENDING = 1

    # Once slots are provisioned, capacity commitment becomes active.
    # slot_count is added to the project's slot_capacity.
    ACTIVE = 2

    # Capacity commitment is failed to be activated by the backend.
    FAILED = 3
  end
end

#edition::Google::Cloud::Bigquery::Reservation::V1::Edition

Returns Optional. Edition of the capacity commitment.

Returns:



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 403

class CapacityCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Commitment plan defines the current committed period. Capacity commitment
  # cannot be deleted during it's committed period.
  module CommitmentPlan
    # Invalid plan value. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    COMMITMENT_PLAN_UNSPECIFIED = 0

    # Flex commitments have committed period of 1 minute after becoming ACTIVE.
    # After that, they are not in a committed period anymore and can be removed
    # any time.
    FLEX = 3

    # Same as FLEX, should only be used if flat-rate commitments are still
    # available.
    FLEX_FLAT_RATE = 7

    # Trial commitments have a committed period of 182 days after becoming
    # ACTIVE. After that, they are converted to a new commitment based on the
    # `renewal_plan`. Default `renewal_plan` for Trial commitment is Flex so
    # that it can be deleted right after committed period ends.
    TRIAL = 5

    # Monthly commitments have a committed period of 30 days after becoming
    # ACTIVE. After that, they are not in a committed period anymore and can be
    # removed any time.
    MONTHLY = 2

    # Same as MONTHLY, should only be used if flat-rate commitments are still
    # available.
    MONTHLY_FLAT_RATE = 8

    # Annual commitments have a committed period of 365 days after becoming
    # ACTIVE. After that they are converted to a new commitment based on the
    # renewal_plan.
    ANNUAL = 4

    # Same as ANNUAL, should only be used if flat-rate commitments are still
    # available.
    ANNUAL_FLAT_RATE = 9

    # 3-year commitments have a committed period of 1095(3 * 365) days after
    # becoming ACTIVE. After that they are converted to a new commitment based
    # on the renewal_plan.
    THREE_YEAR = 10

    # Should only be used for `renewal_plan` and is only meaningful if
    # edition is specified to values other than EDITION_UNSPECIFIED. Otherwise
    # CreateCapacityCommitmentRequest or UpdateCapacityCommitmentRequest will
    # be rejected with error code `google.rpc.Code.INVALID_ARGUMENT`. If the
    # renewal_plan is NONE, capacity commitment will be removed at the end of
    # its commitment period.
    NONE = 6
  end

  # Capacity commitment can either become ACTIVE right away or transition
  # from PENDING to ACTIVE or FAILED.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Capacity commitment is pending provisioning. Pending capacity commitment
    # does not contribute to the project's slot_capacity.
    PENDING = 1

    # Once slots are provisioned, capacity commitment becomes active.
    # slot_count is added to the project's slot_capacity.
    ACTIVE = 2

    # Capacity commitment is failed to be activated by the backend.
    FAILED = 3
  end
end

#failure_status::Google::Rpc::Status (readonly)

Returns Output only. For FAILED commitment plan, provides the reason of failure.

Returns:



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 403

class CapacityCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Commitment plan defines the current committed period. Capacity commitment
  # cannot be deleted during it's committed period.
  module CommitmentPlan
    # Invalid plan value. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    COMMITMENT_PLAN_UNSPECIFIED = 0

    # Flex commitments have committed period of 1 minute after becoming ACTIVE.
    # After that, they are not in a committed period anymore and can be removed
    # any time.
    FLEX = 3

    # Same as FLEX, should only be used if flat-rate commitments are still
    # available.
    FLEX_FLAT_RATE = 7

    # Trial commitments have a committed period of 182 days after becoming
    # ACTIVE. After that, they are converted to a new commitment based on the
    # `renewal_plan`. Default `renewal_plan` for Trial commitment is Flex so
    # that it can be deleted right after committed period ends.
    TRIAL = 5

    # Monthly commitments have a committed period of 30 days after becoming
    # ACTIVE. After that, they are not in a committed period anymore and can be
    # removed any time.
    MONTHLY = 2

    # Same as MONTHLY, should only be used if flat-rate commitments are still
    # available.
    MONTHLY_FLAT_RATE = 8

    # Annual commitments have a committed period of 365 days after becoming
    # ACTIVE. After that they are converted to a new commitment based on the
    # renewal_plan.
    ANNUAL = 4

    # Same as ANNUAL, should only be used if flat-rate commitments are still
    # available.
    ANNUAL_FLAT_RATE = 9

    # 3-year commitments have a committed period of 1095(3 * 365) days after
    # becoming ACTIVE. After that they are converted to a new commitment based
    # on the renewal_plan.
    THREE_YEAR = 10

    # Should only be used for `renewal_plan` and is only meaningful if
    # edition is specified to values other than EDITION_UNSPECIFIED. Otherwise
    # CreateCapacityCommitmentRequest or UpdateCapacityCommitmentRequest will
    # be rejected with error code `google.rpc.Code.INVALID_ARGUMENT`. If the
    # renewal_plan is NONE, capacity commitment will be removed at the end of
    # its commitment period.
    NONE = 6
  end

  # Capacity commitment can either become ACTIVE right away or transition
  # from PENDING to ACTIVE or FAILED.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Capacity commitment is pending provisioning. Pending capacity commitment
    # does not contribute to the project's slot_capacity.
    PENDING = 1

    # Once slots are provisioned, capacity commitment becomes active.
    # slot_count is added to the project's slot_capacity.
    ACTIVE = 2

    # Capacity commitment is failed to be activated by the backend.
    FAILED = 3
  end
end

#is_flat_rate::Boolean (readonly)

Returns Output only. If true, the commitment is a flat-rate commitment, otherwise, it's an edition commitment.

Returns:

  • (::Boolean)

    Output only. If true, the commitment is a flat-rate commitment, otherwise, it's an edition commitment.



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 403

class CapacityCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Commitment plan defines the current committed period. Capacity commitment
  # cannot be deleted during it's committed period.
  module CommitmentPlan
    # Invalid plan value. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    COMMITMENT_PLAN_UNSPECIFIED = 0

    # Flex commitments have committed period of 1 minute after becoming ACTIVE.
    # After that, they are not in a committed period anymore and can be removed
    # any time.
    FLEX = 3

    # Same as FLEX, should only be used if flat-rate commitments are still
    # available.
    FLEX_FLAT_RATE = 7

    # Trial commitments have a committed period of 182 days after becoming
    # ACTIVE. After that, they are converted to a new commitment based on the
    # `renewal_plan`. Default `renewal_plan` for Trial commitment is Flex so
    # that it can be deleted right after committed period ends.
    TRIAL = 5

    # Monthly commitments have a committed period of 30 days after becoming
    # ACTIVE. After that, they are not in a committed period anymore and can be
    # removed any time.
    MONTHLY = 2

    # Same as MONTHLY, should only be used if flat-rate commitments are still
    # available.
    MONTHLY_FLAT_RATE = 8

    # Annual commitments have a committed period of 365 days after becoming
    # ACTIVE. After that they are converted to a new commitment based on the
    # renewal_plan.
    ANNUAL = 4

    # Same as ANNUAL, should only be used if flat-rate commitments are still
    # available.
    ANNUAL_FLAT_RATE = 9

    # 3-year commitments have a committed period of 1095(3 * 365) days after
    # becoming ACTIVE. After that they are converted to a new commitment based
    # on the renewal_plan.
    THREE_YEAR = 10

    # Should only be used for `renewal_plan` and is only meaningful if
    # edition is specified to values other than EDITION_UNSPECIFIED. Otherwise
    # CreateCapacityCommitmentRequest or UpdateCapacityCommitmentRequest will
    # be rejected with error code `google.rpc.Code.INVALID_ARGUMENT`. If the
    # renewal_plan is NONE, capacity commitment will be removed at the end of
    # its commitment period.
    NONE = 6
  end

  # Capacity commitment can either become ACTIVE right away or transition
  # from PENDING to ACTIVE or FAILED.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Capacity commitment is pending provisioning. Pending capacity commitment
    # does not contribute to the project's slot_capacity.
    PENDING = 1

    # Once slots are provisioned, capacity commitment becomes active.
    # slot_count is added to the project's slot_capacity.
    ACTIVE = 2

    # Capacity commitment is failed to be activated by the backend.
    FAILED = 3
  end
end

#multi_region_auxiliary::Boolean

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Applicable only for commitments located within one of the BigQuery multi-regions (US or EU).

If set to true, this commitment is placed in the organization's secondary region which is designated for disaster recovery purposes. If false, this commitment is placed in the organization's default region.

NOTE: this is a preview feature. Project must be allow-listed in order to set this field.

Returns:

  • (::Boolean)

    Applicable only for commitments located within one of the BigQuery multi-regions (US or EU).

    If set to true, this commitment is placed in the organization's secondary region which is designated for disaster recovery purposes. If false, this commitment is placed in the organization's default region.

    NOTE: this is a preview feature. Project must be allow-listed in order to set this field.



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 403

class CapacityCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Commitment plan defines the current committed period. Capacity commitment
  # cannot be deleted during it's committed period.
  module CommitmentPlan
    # Invalid plan value. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    COMMITMENT_PLAN_UNSPECIFIED = 0

    # Flex commitments have committed period of 1 minute after becoming ACTIVE.
    # After that, they are not in a committed period anymore and can be removed
    # any time.
    FLEX = 3

    # Same as FLEX, should only be used if flat-rate commitments are still
    # available.
    FLEX_FLAT_RATE = 7

    # Trial commitments have a committed period of 182 days after becoming
    # ACTIVE. After that, they are converted to a new commitment based on the
    # `renewal_plan`. Default `renewal_plan` for Trial commitment is Flex so
    # that it can be deleted right after committed period ends.
    TRIAL = 5

    # Monthly commitments have a committed period of 30 days after becoming
    # ACTIVE. After that, they are not in a committed period anymore and can be
    # removed any time.
    MONTHLY = 2

    # Same as MONTHLY, should only be used if flat-rate commitments are still
    # available.
    MONTHLY_FLAT_RATE = 8

    # Annual commitments have a committed period of 365 days after becoming
    # ACTIVE. After that they are converted to a new commitment based on the
    # renewal_plan.
    ANNUAL = 4

    # Same as ANNUAL, should only be used if flat-rate commitments are still
    # available.
    ANNUAL_FLAT_RATE = 9

    # 3-year commitments have a committed period of 1095(3 * 365) days after
    # becoming ACTIVE. After that they are converted to a new commitment based
    # on the renewal_plan.
    THREE_YEAR = 10

    # Should only be used for `renewal_plan` and is only meaningful if
    # edition is specified to values other than EDITION_UNSPECIFIED. Otherwise
    # CreateCapacityCommitmentRequest or UpdateCapacityCommitmentRequest will
    # be rejected with error code `google.rpc.Code.INVALID_ARGUMENT`. If the
    # renewal_plan is NONE, capacity commitment will be removed at the end of
    # its commitment period.
    NONE = 6
  end

  # Capacity commitment can either become ACTIVE right away or transition
  # from PENDING to ACTIVE or FAILED.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Capacity commitment is pending provisioning. Pending capacity commitment
    # does not contribute to the project's slot_capacity.
    PENDING = 1

    # Once slots are provisioned, capacity commitment becomes active.
    # slot_count is added to the project's slot_capacity.
    ACTIVE = 2

    # Capacity commitment is failed to be activated by the backend.
    FAILED = 3
  end
end

#name::String (readonly)

Returns Output only. The resource name of the capacity commitment, e.g., projects/myproject/locations/US/capacityCommitments/123 The commitment_id must only contain lower case alphanumeric characters or dashes. It must start with a letter and must not end with a dash. Its maximum length is 64 characters.

Returns:

  • (::String)

    Output only. The resource name of the capacity commitment, e.g., projects/myproject/locations/US/capacityCommitments/123 The commitment_id must only contain lower case alphanumeric characters or dashes. It must start with a letter and must not end with a dash. Its maximum length is 64 characters.



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 403

class CapacityCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Commitment plan defines the current committed period. Capacity commitment
  # cannot be deleted during it's committed period.
  module CommitmentPlan
    # Invalid plan value. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    COMMITMENT_PLAN_UNSPECIFIED = 0

    # Flex commitments have committed period of 1 minute after becoming ACTIVE.
    # After that, they are not in a committed period anymore and can be removed
    # any time.
    FLEX = 3

    # Same as FLEX, should only be used if flat-rate commitments are still
    # available.
    FLEX_FLAT_RATE = 7

    # Trial commitments have a committed period of 182 days after becoming
    # ACTIVE. After that, they are converted to a new commitment based on the
    # `renewal_plan`. Default `renewal_plan` for Trial commitment is Flex so
    # that it can be deleted right after committed period ends.
    TRIAL = 5

    # Monthly commitments have a committed period of 30 days after becoming
    # ACTIVE. After that, they are not in a committed period anymore and can be
    # removed any time.
    MONTHLY = 2

    # Same as MONTHLY, should only be used if flat-rate commitments are still
    # available.
    MONTHLY_FLAT_RATE = 8

    # Annual commitments have a committed period of 365 days after becoming
    # ACTIVE. After that they are converted to a new commitment based on the
    # renewal_plan.
    ANNUAL = 4

    # Same as ANNUAL, should only be used if flat-rate commitments are still
    # available.
    ANNUAL_FLAT_RATE = 9

    # 3-year commitments have a committed period of 1095(3 * 365) days after
    # becoming ACTIVE. After that they are converted to a new commitment based
    # on the renewal_plan.
    THREE_YEAR = 10

    # Should only be used for `renewal_plan` and is only meaningful if
    # edition is specified to values other than EDITION_UNSPECIFIED. Otherwise
    # CreateCapacityCommitmentRequest or UpdateCapacityCommitmentRequest will
    # be rejected with error code `google.rpc.Code.INVALID_ARGUMENT`. If the
    # renewal_plan is NONE, capacity commitment will be removed at the end of
    # its commitment period.
    NONE = 6
  end

  # Capacity commitment can either become ACTIVE right away or transition
  # from PENDING to ACTIVE or FAILED.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Capacity commitment is pending provisioning. Pending capacity commitment
    # does not contribute to the project's slot_capacity.
    PENDING = 1

    # Once slots are provisioned, capacity commitment becomes active.
    # slot_count is added to the project's slot_capacity.
    ACTIVE = 2

    # Capacity commitment is failed to be activated by the backend.
    FAILED = 3
  end
end

#plan::Google::Cloud::Bigquery::Reservation::V1::CapacityCommitment::CommitmentPlan

Returns Optional. Capacity commitment commitment plan.

Returns:



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 403

class CapacityCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Commitment plan defines the current committed period. Capacity commitment
  # cannot be deleted during it's committed period.
  module CommitmentPlan
    # Invalid plan value. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    COMMITMENT_PLAN_UNSPECIFIED = 0

    # Flex commitments have committed period of 1 minute after becoming ACTIVE.
    # After that, they are not in a committed period anymore and can be removed
    # any time.
    FLEX = 3

    # Same as FLEX, should only be used if flat-rate commitments are still
    # available.
    FLEX_FLAT_RATE = 7

    # Trial commitments have a committed period of 182 days after becoming
    # ACTIVE. After that, they are converted to a new commitment based on the
    # `renewal_plan`. Default `renewal_plan` for Trial commitment is Flex so
    # that it can be deleted right after committed period ends.
    TRIAL = 5

    # Monthly commitments have a committed period of 30 days after becoming
    # ACTIVE. After that, they are not in a committed period anymore and can be
    # removed any time.
    MONTHLY = 2

    # Same as MONTHLY, should only be used if flat-rate commitments are still
    # available.
    MONTHLY_FLAT_RATE = 8

    # Annual commitments have a committed period of 365 days after becoming
    # ACTIVE. After that they are converted to a new commitment based on the
    # renewal_plan.
    ANNUAL = 4

    # Same as ANNUAL, should only be used if flat-rate commitments are still
    # available.
    ANNUAL_FLAT_RATE = 9

    # 3-year commitments have a committed period of 1095(3 * 365) days after
    # becoming ACTIVE. After that they are converted to a new commitment based
    # on the renewal_plan.
    THREE_YEAR = 10

    # Should only be used for `renewal_plan` and is only meaningful if
    # edition is specified to values other than EDITION_UNSPECIFIED. Otherwise
    # CreateCapacityCommitmentRequest or UpdateCapacityCommitmentRequest will
    # be rejected with error code `google.rpc.Code.INVALID_ARGUMENT`. If the
    # renewal_plan is NONE, capacity commitment will be removed at the end of
    # its commitment period.
    NONE = 6
  end

  # Capacity commitment can either become ACTIVE right away or transition
  # from PENDING to ACTIVE or FAILED.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Capacity commitment is pending provisioning. Pending capacity commitment
    # does not contribute to the project's slot_capacity.
    PENDING = 1

    # Once slots are provisioned, capacity commitment becomes active.
    # slot_count is added to the project's slot_capacity.
    ACTIVE = 2

    # Capacity commitment is failed to be activated by the backend.
    FAILED = 3
  end
end

#renewal_plan::Google::Cloud::Bigquery::Reservation::V1::CapacityCommitment::CommitmentPlan

Returns Optional. The plan this capacity commitment is converted to after commitment_end_time passes. Once the plan is changed, committed period is extended according to commitment plan. Only applicable for ANNUAL and TRIAL commitments.

Returns:



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 403

class CapacityCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Commitment plan defines the current committed period. Capacity commitment
  # cannot be deleted during it's committed period.
  module CommitmentPlan
    # Invalid plan value. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    COMMITMENT_PLAN_UNSPECIFIED = 0

    # Flex commitments have committed period of 1 minute after becoming ACTIVE.
    # After that, they are not in a committed period anymore and can be removed
    # any time.
    FLEX = 3

    # Same as FLEX, should only be used if flat-rate commitments are still
    # available.
    FLEX_FLAT_RATE = 7

    # Trial commitments have a committed period of 182 days after becoming
    # ACTIVE. After that, they are converted to a new commitment based on the
    # `renewal_plan`. Default `renewal_plan` for Trial commitment is Flex so
    # that it can be deleted right after committed period ends.
    TRIAL = 5

    # Monthly commitments have a committed period of 30 days after becoming
    # ACTIVE. After that, they are not in a committed period anymore and can be
    # removed any time.
    MONTHLY = 2

    # Same as MONTHLY, should only be used if flat-rate commitments are still
    # available.
    MONTHLY_FLAT_RATE = 8

    # Annual commitments have a committed period of 365 days after becoming
    # ACTIVE. After that they are converted to a new commitment based on the
    # renewal_plan.
    ANNUAL = 4

    # Same as ANNUAL, should only be used if flat-rate commitments are still
    # available.
    ANNUAL_FLAT_RATE = 9

    # 3-year commitments have a committed period of 1095(3 * 365) days after
    # becoming ACTIVE. After that they are converted to a new commitment based
    # on the renewal_plan.
    THREE_YEAR = 10

    # Should only be used for `renewal_plan` and is only meaningful if
    # edition is specified to values other than EDITION_UNSPECIFIED. Otherwise
    # CreateCapacityCommitmentRequest or UpdateCapacityCommitmentRequest will
    # be rejected with error code `google.rpc.Code.INVALID_ARGUMENT`. If the
    # renewal_plan is NONE, capacity commitment will be removed at the end of
    # its commitment period.
    NONE = 6
  end

  # Capacity commitment can either become ACTIVE right away or transition
  # from PENDING to ACTIVE or FAILED.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Capacity commitment is pending provisioning. Pending capacity commitment
    # does not contribute to the project's slot_capacity.
    PENDING = 1

    # Once slots are provisioned, capacity commitment becomes active.
    # slot_count is added to the project's slot_capacity.
    ACTIVE = 2

    # Capacity commitment is failed to be activated by the backend.
    FAILED = 3
  end
end

#slot_count::Integer

Returns Optional. Number of slots in this commitment.

Returns:

  • (::Integer)

    Optional. Number of slots in this commitment.



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 403

class CapacityCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Commitment plan defines the current committed period. Capacity commitment
  # cannot be deleted during it's committed period.
  module CommitmentPlan
    # Invalid plan value. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    COMMITMENT_PLAN_UNSPECIFIED = 0

    # Flex commitments have committed period of 1 minute after becoming ACTIVE.
    # After that, they are not in a committed period anymore and can be removed
    # any time.
    FLEX = 3

    # Same as FLEX, should only be used if flat-rate commitments are still
    # available.
    FLEX_FLAT_RATE = 7

    # Trial commitments have a committed period of 182 days after becoming
    # ACTIVE. After that, they are converted to a new commitment based on the
    # `renewal_plan`. Default `renewal_plan` for Trial commitment is Flex so
    # that it can be deleted right after committed period ends.
    TRIAL = 5

    # Monthly commitments have a committed period of 30 days after becoming
    # ACTIVE. After that, they are not in a committed period anymore and can be
    # removed any time.
    MONTHLY = 2

    # Same as MONTHLY, should only be used if flat-rate commitments are still
    # available.
    MONTHLY_FLAT_RATE = 8

    # Annual commitments have a committed period of 365 days after becoming
    # ACTIVE. After that they are converted to a new commitment based on the
    # renewal_plan.
    ANNUAL = 4

    # Same as ANNUAL, should only be used if flat-rate commitments are still
    # available.
    ANNUAL_FLAT_RATE = 9

    # 3-year commitments have a committed period of 1095(3 * 365) days after
    # becoming ACTIVE. After that they are converted to a new commitment based
    # on the renewal_plan.
    THREE_YEAR = 10

    # Should only be used for `renewal_plan` and is only meaningful if
    # edition is specified to values other than EDITION_UNSPECIFIED. Otherwise
    # CreateCapacityCommitmentRequest or UpdateCapacityCommitmentRequest will
    # be rejected with error code `google.rpc.Code.INVALID_ARGUMENT`. If the
    # renewal_plan is NONE, capacity commitment will be removed at the end of
    # its commitment period.
    NONE = 6
  end

  # Capacity commitment can either become ACTIVE right away or transition
  # from PENDING to ACTIVE or FAILED.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Capacity commitment is pending provisioning. Pending capacity commitment
    # does not contribute to the project's slot_capacity.
    PENDING = 1

    # Once slots are provisioned, capacity commitment becomes active.
    # slot_count is added to the project's slot_capacity.
    ACTIVE = 2

    # Capacity commitment is failed to be activated by the backend.
    FAILED = 3
  end
end

#state::Google::Cloud::Bigquery::Reservation::V1::CapacityCommitment::State (readonly)

Returns Output only. State of the commitment.

Returns:



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 403

class CapacityCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Commitment plan defines the current committed period. Capacity commitment
  # cannot be deleted during it's committed period.
  module CommitmentPlan
    # Invalid plan value. Requests with this value will be rejected with
    # error code `google.rpc.Code.INVALID_ARGUMENT`.
    COMMITMENT_PLAN_UNSPECIFIED = 0

    # Flex commitments have committed period of 1 minute after becoming ACTIVE.
    # After that, they are not in a committed period anymore and can be removed
    # any time.
    FLEX = 3

    # Same as FLEX, should only be used if flat-rate commitments are still
    # available.
    FLEX_FLAT_RATE = 7

    # Trial commitments have a committed period of 182 days after becoming
    # ACTIVE. After that, they are converted to a new commitment based on the
    # `renewal_plan`. Default `renewal_plan` for Trial commitment is Flex so
    # that it can be deleted right after committed period ends.
    TRIAL = 5

    # Monthly commitments have a committed period of 30 days after becoming
    # ACTIVE. After that, they are not in a committed period anymore and can be
    # removed any time.
    MONTHLY = 2

    # Same as MONTHLY, should only be used if flat-rate commitments are still
    # available.
    MONTHLY_FLAT_RATE = 8

    # Annual commitments have a committed period of 365 days after becoming
    # ACTIVE. After that they are converted to a new commitment based on the
    # renewal_plan.
    ANNUAL = 4

    # Same as ANNUAL, should only be used if flat-rate commitments are still
    # available.
    ANNUAL_FLAT_RATE = 9

    # 3-year commitments have a committed period of 1095(3 * 365) days after
    # becoming ACTIVE. After that they are converted to a new commitment based
    # on the renewal_plan.
    THREE_YEAR = 10

    # Should only be used for `renewal_plan` and is only meaningful if
    # edition is specified to values other than EDITION_UNSPECIFIED. Otherwise
    # CreateCapacityCommitmentRequest or UpdateCapacityCommitmentRequest will
    # be rejected with error code `google.rpc.Code.INVALID_ARGUMENT`. If the
    # renewal_plan is NONE, capacity commitment will be removed at the end of
    # its commitment period.
    NONE = 6
  end

  # Capacity commitment can either become ACTIVE right away or transition
  # from PENDING to ACTIVE or FAILED.
  module State
    # Invalid state value.
    STATE_UNSPECIFIED = 0

    # Capacity commitment is pending provisioning. Pending capacity commitment
    # does not contribute to the project's slot_capacity.
    PENDING = 1

    # Once slots are provisioned, capacity commitment becomes active.
    # slot_count is added to the project's slot_capacity.
    ACTIVE = 2

    # Capacity commitment is failed to be activated by the backend.
    FAILED = 3
  end
end