Class: Google::Cloud::Bigquery::Reservation::V1::CreateAssignmentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Bigquery::Reservation::V1::CreateAssignmentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb
Overview
The request for ReservationService.CreateAssignment. Note: "bigquery.reservationAssignments.create" permission is required on the related assignee.
Instance Attribute Summary collapse
-
#assignment ⇒ ::Google::Cloud::Bigquery::Reservation::V1::Assignment
Assignment resource to create.
-
#assignment_id ⇒ ::String
The optional assignment ID.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#assignment ⇒ ::Google::Cloud::Bigquery::Reservation::V1::Assignment
Returns Assignment resource to create.
928 929 930 931 |
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 928 class CreateAssignmentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#assignment_id ⇒ ::String
Returns The optional assignment ID. Assignment name will be generated automatically if this field is empty. This field must only contain lower case alphanumeric characters or dashes. Max length is 64 characters.
928 929 930 931 |
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 928 class CreateAssignmentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource name of the assignment
E.g. projects/myproject/locations/US/reservations/team1-prod.
928 929 930 931 |
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 928 class CreateAssignmentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |