Class: Google::Cloud::Bigquery::Reservation::V1::DeleteCapacityCommitmentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#force::Boolean

Returns Can be used to force delete commitments even if assignments exist. Deleting commitments with assignments may cause queries to fail if they no longer have access to slots.

Returns:

  • (::Boolean)

    Can be used to force delete commitments even if assignments exist. Deleting commitments with assignments may cause queries to fail if they no longer have access to slots.



730
731
732
733
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 730

class DeleteCapacityCommitmentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. Resource name of the capacity commitment to delete. E.g., projects/myproject/locations/US/capacityCommitments/123.

Returns:

  • (::String)

    Required. Resource name of the capacity commitment to delete. E.g., projects/myproject/locations/US/capacityCommitments/123



730
731
732
733
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 730

class DeleteCapacityCommitmentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end