Module: Google::Cloud::Bigquery::Reservation::V1::FailoverMode
- Defined in:
- proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb
Overview
The failover mode when a user initiates a failover on a reservation determines how writes that are pending replication are handled after the failover is initiated.
Constant Summary collapse
- FAILOVER_MODE_UNSPECIFIED =
Invalid value.
0- SOFT =
When customers initiate a soft failover, BigQuery will wait until all committed writes are replicated to the secondary. This mode requires both regions to be available for the failover to succeed and prevents data loss.
1- HARD =
When customers initiate a hard failover, BigQuery will not wait until all committed writes are replicated to the secondary. There can be data loss for hard failover.
2