Class: Google::Cloud::Bigquery::Reservation::V1::MergeCapacityCommitmentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_commitment_id::String

Returns Optional. The optional resulting capacity commitment ID. Capacity commitment name will be generated automatically if this field is empty. This field must only contain lower case alphanumeric characters or dashes. The first and last character cannot be a dash. Max length is 64 characters.

Returns:

  • (::String)

    Optional. The optional resulting capacity commitment ID. Capacity commitment name will be generated automatically if this field is empty. This field must only contain lower case alphanumeric characters or dashes. The first and last character cannot be a dash. Max length is 64 characters.



794
795
796
797
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 794

class MergeCapacityCommitmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#capacity_commitment_ids::Array<::String>

Returns Ids of capacity commitments to merge. These capacity commitments must exist under admin project and location specified in the parent. ID is the last portion of capacity commitment name e.g., 'abc' for projects/myproject/locations/US/capacityCommitments/abc.

Returns:

  • (::Array<::String>)

    Ids of capacity commitments to merge. These capacity commitments must exist under admin project and location specified in the parent. ID is the last portion of capacity commitment name e.g., 'abc' for projects/myproject/locations/US/capacityCommitments/abc



794
795
796
797
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 794

class MergeCapacityCommitmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Parent resource that identifies admin project and location e.g., projects/myproject/locations/us.

Returns:

  • (::String)

    Parent resource that identifies admin project and location e.g., projects/myproject/locations/us



794
795
796
797
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 794

class MergeCapacityCommitmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end