Class: Google::Cloud::Bigquery::Reservation::V1::Reservation::ReplicationStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb

Overview

Disaster Recovery(DR) replication status of the reservation.

Instance Attribute Summary collapse

Instance Attribute Details

#error::Google::Rpc::Status (readonly)

Returns Output only. The last error encountered while trying to replicate changes from the primary to the secondary. This field is only available if the replication has not succeeded since.

Returns:

  • (::Google::Rpc::Status)

    Output only. The last error encountered while trying to replicate changes from the primary to the secondary. This field is only available if the replication has not succeeded since.



229
230
231
232
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 229

class ReplicationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#last_error_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the last error was encountered while trying to replicate changes from the primary to the secondary. This field is only available if the replication has not succeeded since.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The time at which the last error was encountered while trying to replicate changes from the primary to the secondary. This field is only available if the replication has not succeeded since.



229
230
231
232
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 229

class ReplicationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#last_replication_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. A timestamp corresponding to the last change on the primary that was successfully replicated to the secondary.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. A timestamp corresponding to the last change on the primary that was successfully replicated to the secondary.



229
230
231
232
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 229

class ReplicationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#soft_failover_start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which a soft failover for the reservation and its associated datasets was initiated. After this field is set, all subsequent changes to the reservation will be rejected unless a hard failover overrides this operation. This field will be cleared once the failover is complete.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The time at which a soft failover for the reservation and its associated datasets was initiated. After this field is set, all subsequent changes to the reservation will be rejected unless a hard failover overrides this operation. This field will be cleared once the failover is complete.



229
230
231
232
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 229

class ReplicationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end