Class: Google::Cloud::Bigquery::Reservation::V1::ReservationGroup

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb

Overview

A reservation group is a container for reservations.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Identifier. The resource name of the reservation group, e.g., projects/*/locations/*/reservationGroups/team1-prod. The reservation_group_id must only contain lower case alphanumeric characters or dashes. It must start with a letter and must not end with a dash. Its maximum length is 64 characters.

Returns:

  • (::String)

    Identifier. The resource name of the reservation group, e.g., projects/*/locations/*/reservationGroups/team1-prod. The reservation_group_id must only contain lower case alphanumeric characters or dashes. It must start with a letter and must not end with a dash. Its maximum length is 64 characters.



331
332
333
334
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 331

class ReservationGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end