Class: Google::Cloud::Bigquery::Reservation::V1::SchedulingPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb

Overview

The scheduling policy controls how a reservation's resources are distributed.

Instance Attribute Summary collapse

Instance Attribute Details

#concurrency::Integer

Returns Optional. If present and > 0, the reservation will attempt to limit the concurrency of jobs running for any particular project within it to the given value.

This feature is not yet generally available.

Returns:

  • (::Integer)

    Optional. If present and > 0, the reservation will attempt to limit the concurrency of jobs running for any particular project within it to the given value.

    This feature is not yet generally available.



318
319
320
321
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 318

class SchedulingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_slots::Integer

Returns Optional. If present and > 0, the reservation will attempt to limit the slot consumption of queries running for any particular project within it to the given value.

This feature is not yet generally available.

Returns:

  • (::Integer)

    Optional. If present and > 0, the reservation will attempt to limit the slot consumption of queries running for any particular project within it to the given value.

    This feature is not yet generally available.



318
319
320
321
# File 'proto_docs/google/cloud/bigquery/reservation/v1/reservation.rb', line 318

class SchedulingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end